Log Scale | Chart.js
Description: Open source HTML5 Charts for your website

# # Log Scale

const config = { type: 'line', data: data, options: { responsive: true, plugins: { title: { display: true, text: 'Chart.js Line Chart - Logarithmic' } }, scales: { x: { display: true, }, y: { display: true, type: 'logarithmic', } } }, };

    const config = {
      type: 'line',
      data: data,
      options: {
        responsive: true,
        plugins: {
          title: {
            display: true,
            text: 'Chart.js Line Chart - Logarithmic'
          }
        },
        scales: {
          x: {
            display: true,
          },
          y: {
            display: true,
            type: 'logarithmic',
          }
        }
      },
    };

const DATA_COUNT = 7; const NUMBER_CFG = {count: DATA_COUNT, min: 0, max: 100}; const labels = Utils.months({count: 7}); const data = { labels: labels, datasets: [ { label: 'Dataset 1', data: logNumbers(DATA_COUNT), borderColor: Utils.CHART_COLORS.red, backgroundColor: Utils.CHART_COLORS.red, fill: false, }, ] };

    const DATA_COUNT = 7;
    const NUMBER_CFG = {count: DATA_COUNT, min: 0, max: 100};
    const labels = Utils.months({count: 7});
    const data = {
      labels: labels,
      datasets: [
        {
          label: 'Dataset 1',
          data: logNumbers(DATA_COUNT),
          borderColor: Utils.CHART_COLORS.red,
          backgroundColor: Utils.CHART_COLORS.red,
          fill: false,
        },
      ]
    };

const logNumbers = (num) => { const data = []; for (let i = 0; i < num; ++i) { data.push(Math.ceil(Math.random() * 10.0) * Math.pow(10, Math.ceil(Math.random() * 5))); } return data; }; const actions = [ { name: 'Randomize', handler(chart) { chart.data.datasets.forEach(dataset => { dataset.data = logNumbers(chart.data.labels.length); }); chart.update(); } }, ];

    const logNumbers = (num) => {
      const data = [];
      for (let i = 0; i < num; ++i) {
        data.push(Math.ceil(Math.random() * 10.0) * Math.pow(10, Math.ceil(Math.random() * 5)));
      }
      return data;
    };
    const actions = [
      {
        name: 'Randomize',
        handler(chart) {
          chart.data.datasets.forEach(dataset => {
            dataset.data = logNumbers(chart.data.labels.length);
          });
          chart.update();
        }
      },
    ];

## # Docs

- Line
- Logarithmic Axis
- Data structures (`labels`)